.. _WdColorIndex:

``WD_COLOR_INDEX``
==================

alias: **WD_COLOR**

Specifies a standard preset color to apply. Used for font highlighting and
perhaps other applications.

----

AUTO
    Automatic color. Default; usually black.

BLACK
    Black color.

BLUE
    Blue color

BRIGHT_GREEN
    Bright green color.

DARK_BLUE
    Dark blue color.

DARK_RED
    Dark red color.

DARK_YELLOW
    Dark yellow color.

GRAY_25
    25% shade of gray color.

GRAY_50
    50% shade of gray color.

GREEN
    Green color.

PINK
    Pink color.

RED
    Red color.

TEAL
    Teal color.

TURQUOISE
    Turquoise color.

VIOLET
    Violet color.

WHITE
    White color.

YELLOW
    Yellow color.
